####################################################################################################################################################
####################################################################################################################################################
"""
Compute performances and metrics for several seed runs.
Make sure to provide 10 runs of the same kind of experiments.
"""
####################################################################################################################################################
####################################################################################################################################################

import toml
import numpy as np
from pathlib import Path

####################################################################################################################################################
####################################################################################################################################################

def get_row(experiment):

    assert len(experiments) == 10

    old_train = ""

    # keep track
    all_results = []

    for experiment in experiments:

        # get the config file to get the training data
        config_file = Path("results") / experiment / "cfg.toml"
        config = toml.load(config_file)
        train = config["dataset"]["name"]

        if old_train != "":
            if train != old_train:
                raise ValueError("Not all models are from the same dataset")

        result_file = Path("results") / experiment / "logs" / "test_accuracy_linear.performance"

        # get the value
        with result_file.open("r") as f:
            value = float(f.readlines()[0])*100

        # keep track of the value
        all_results.append(value)

        old_train = train


    all_results = np.array(all_results)
    mean_results = np.mean(all_results)
    std_results = np.std(all_results)

    print("-"*77)
    print(experiment)
    print(f"Training: \t\t {train}")
    print("-"*77)
    print(f"{mean_results:.1f} \pm {std_results:.1f}")

####################################################################################################################################################

if __name__ == "__main__":

    experiments = [

      
        
    ]

    get_row(experiments)